tdub.rex_art
------------

A module for creating art from TRExFitter. The contents of this module
should nominally be avoided as an end user; the command line interface
is preferred. See the help messages from ``tdub stacks`` and ``tdub
pulls``.

.. currentmodule:: tdub.old.rex_art

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   NuisPar

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   run_pulls

Reference
^^^^^^^^^

.. autoclass:: NuisPar
   :members:

.. autofunction:: run_pulls
